(function() {
  var Akismet, http, qs, util;
  http = require('http');
  qs = require('querystring');
  util = require('util');
  Akismet = (function() {
    function Akismet(options) {
      this.blog = options.blog || '';
      this.apiKey = options.apiKey;
      this.host = options.host || 'rest.akismet.com';
      this.endPoint = options.endPoint || this.apiKey + '.' + this.host;
      this.port = options.port || 80;
      this.userAgent = options.userAgent || 'Generic Node.js/1.0.0 | Akismet 2.4.0';
      this.charset = options.charset || 'utf-8';
      this.debug = options.debug || false;
      this.keyClient = null;
      this.client = null;
    }
    Akismet.prototype.verifyKey = function(callback) {
      callback || (callback = function() {});
      this.keyClient || (this.keyClient = http.createClient(this.port, this.host));
      return this.postRequest(this.keyClient, '/1.1/verify-key', {
        key: this.apiKey,
        blog: this.blog
      }, function(err, status, headers, body) {
        return callback(err, (status >= 200 && status < 300 && body === 'valid' ? true : false), status, headers);
      });
    };
    Akismet.prototype.checkSpam = function(options, callback) {
      callback || (callback = function() {});
      options.blog = this.blog;
      options.user_agent = this.userAgent;
      this.client || (this.client = http.createClient(this.port, this.endPoint));
      return this.postRequest(this.client, '/1.1/comment-check', options, function(err, status, headers, body) {
        return callback(err, (status >= 200 && status < 300 && body === 'true' ? true : false), status, headers);
      });
    };
    Akismet.prototype.submitSpam = function(options, callback) {
      callback || (callback = function() {});
      options.blog = this.blog;
      options.user_agent = this.userAgent;
      this.client || (this.client = http.createClient(this.port, this.endPoint));
      return this.postRequest(this.client, '/1.1/submit-spam', options, function(err, status, headers, body) {
        return callback(err, status, headers);
      });
    };
    Akismet.prototype.submitHam = function(options, callback) {
      callback || (callback = function() {});
      options.blog = this.blog;
      options.user_agent = this.userAgent;
      this.client || (this.client = http.createClient(this.port, this.endPoint));
      return this.postRequest(this.client, '/1.1/submit-ham', options, function(err, status, headers, body) {
        return callback(err, status, headers);
      });
    };
    Akismet.prototype.postRequest = function(client, path, query, callback) {
      var req;
      try {
        query = qs.stringify(query);
        req = client.request('POST', path, {
          'host': client.host,
          'content-type': 'application/x-www-form-urlencoded; charset=' + this.charset,
          'content-length': query.length,
          'user-agent': this.userAgent
        });
        req.write(query);
        req.end();
        if (this.debug) {
          util.log('Request: ' + util.inspect(req));
        }
        return req.on('response', function(res) {
          if (this.debug) {
            util.log('Response: ' + util.inspect(res));
          }
          res.setEncoding('utf-8');
          return res.on('data', function(body) {
            return callback(null, res.statusCode, res.headers, body);
          });
        });
      } catch (err) {
        return callback(err, null, null, null);
      }
    };
    return Akismet;
  })();
  module.exports = {
    client: function(options) {
      return new Akismet(options);
    }
  };
}).call(this);
